@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-06-01 03:02:37 -0700 (Fri, 01 Jun 2007) $
-# $Revision: 50 $
+# $Date: 2007-06-02 01:26:53 -0700 (Sat, 02 Jun 2007) $
+# $Revision: 66 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,7 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.2.0');
+use version; our $VERSION = qv('0.2.2');
 
 sub base { return shift->{'base'}; }
 
@@ -59,10 +59,10 @@ sub get_session {
         my $value =
               $self->base->simple
             ? $response
-            : $response->{auth_getSession_response}->[0];
+            : $response->{auth_getSession_response}[0];
 
         while ( my ( $key, $val ) = each %field ) {
-            $self->base->$val( $value->{$key}->[0] );
+            $self->base->$val( $value->{$key}[0] );
         }
     }
     else {    # JSON
@@ -102,7 +102,7 @@ WWW::Facebook::API::Auth - Authentication utilities for Client
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Auth version 0.2.0
+This document describes WWW::Facebook::API::Auth version 0.2.2
 
 
 =head1 SYNOPSIS
